@@ -515,18 +515,15 @@ OutgoingMessage.prototype.setHeader = function setHeader(name, value) {
   const key = name.toLowerCase();
   this[outHeadersKey][key] = [name, value];
 
-  switch (key.length) {
-    case 10:
-      if (key === 'connection')
-        this._removedConnection = false;
+  switch (key) {
+    case 'connection':
+      this._removedConnection = false;
       break;
-    case 14:
-      if (key === 'content-length')
-        this._removedContLen = false;
+    case 'content-length':
+      this._removedContLen = false;
       break;
-    case 17:
-      if (key === 'transfer-encoding')
-        this._removedTE = false;
+    case 'transfer-encoding':
+      this._removedTE = false;
       break;
   }
 };
@@ -588,22 +585,18 @@ OutgoingMessage.prototype.removeHeader = function removeHeader(name) {
 
   var key = name.toLowerCase();
 
-  switch (key.length) {
-    case 10:
-      if (key === 'connection')
-        this._removedConnection = true;
+  switch (key) {
+    case 'connection':
+      this._removedConnection = true;
       break;
-    case 14:
-      if (key === 'content-length')
-        this._removedContLen = true;
+    case 'content-length':
+      this._removedContLen = true;
       break;
-    case 17:
-      if (key === 'transfer-encoding')
-        this._removedTE = true;
+    case 'transfer-encoding':
+      this._removedTE = true;
       break;
-    case 4:
-      if (key === 'date')
-        this.sendDate = false;
+    case 'date':
+      this.sendDate = false;
       break;
   }
 
