@@ -143,6 +143,17 @@ function triggerAsyncId() {
 
 const destroyedSymbol = Symbol('destroyed');
 
+let emitBeforeAfterWarning = true;
+function showEmitBeforeAfterWarning() {
+  if (emitBeforeAfterWarning) {
+    process.emitWarning(
+      'asyncResource.emitBefore and emitAfter are deprecated. Please use ' +
+      'asyncResource.runInAsyncScope instead',
+      'DeprecationWarning', 'DEP0098');
+    emitBeforeAfterWarning = false;
+  }
+}
+
 class AsyncResource {
   constructor(type, opts = {}) {
     if (typeof type !== 'string')
@@ -178,15 +189,28 @@ class AsyncResource {
   }
 
   emitBefore() {
+    showEmitBeforeAfterWarning();
     emitBefore(this[async_id_symbol], this[trigger_async_id_symbol]);
     return this;
   }
 
   emitAfter() {
+    showEmitBeforeAfterWarning();
     emitAfter(this[async_id_symbol]);
     return this;
   }
 
+  runInAsyncScope(fn, thisArg, ...args) {
+    emitBefore(this[async_id_symbol], this[trigger_async_id_symbol]);
+    let ret;
+    try {
+      ret = Reflect.apply(fn, thisArg, args);
+    } finally {
+      emitAfter(this[async_id_symbol]);
+    }
+    return ret;
+  }
+
   emitDestroy() {
     this[destroyedSymbol].destroyed = true;
     emitDestroy(this[async_id_symbol]);
