@@ -237,9 +237,7 @@ function assertSize(size) {
 
   if (typeof size !== 'number') {
     err = new errors.TypeError('ERR_INVALID_ARG_TYPE', 'size', 'number', size);
-  } else if (size < 0) {
-    err = new errors.RangeError('ERR_INVALID_OPT_VALUE', 'size', size);
-  } else if (size > kMaxLength) {
+  } else if (size < 0 || size > kMaxLength) {
     err = new errors.RangeError('ERR_INVALID_OPT_VALUE', 'size', size);
   }
 
@@ -364,8 +362,7 @@ function fromArrayBuffer(obj, byteOffset, length) {
     byteOffset = 0;
   } else {
     byteOffset = +byteOffset;
-    // check for NaN
-    if (byteOffset !== byteOffset)
+    if (Number.isNaN(byteOffset))
       byteOffset = 0;
   }
 
@@ -377,12 +374,9 @@ function fromArrayBuffer(obj, byteOffset, length) {
   if (length === undefined) {
     length = maxLength;
   } else {
-    // convert length to non-negative integer
+    // Convert length to non-negative integer.
     length = +length;
-    // Check for NaN
-    if (length !== length) {
-      length = 0;
-    } else if (length > 0) {
+    if (length > 0) {
       if (length > maxLength)
         throw new errors.RangeError('ERR_BUFFER_OUT_OF_BOUNDS', 'length');
     } else {
@@ -405,7 +399,7 @@ function fromObject(obj) {
   }
 
   if (obj.length !== undefined || isAnyArrayBuffer(obj.buffer)) {
-    if (typeof obj.length !== 'number' || obj.length !== obj.length) {
+    if (typeof obj.length !== 'number') {
       return new FastBuffer();
     }
     return fromArrayLike(obj);
@@ -762,8 +756,7 @@ function bidirectionalIndexOf(buffer, val, byteOffset, encoding, dir) {
   // Coerce to Number. Values like null and [] become 0.
   byteOffset = +byteOffset;
   // If the offset is undefined, "foo", {}, coerces to NaN, search whole buffer.
-  // `x !== x`-style conditionals are a faster form of `isNaN(x)`
-  if (byteOffset !== byteOffset) {
+  if (Number.isNaN(byteOffset)) {
     byteOffset = dir ? 0 : buffer.length;
   }
   dir = !!dir;  // Cast to bool.
@@ -994,15 +987,17 @@ function adjustOffset(offset, length) {
   // Use Math.trunc() to convert offset to an integer value that can be larger
   // than an Int32. Hence, don't use offset | 0 or similar techniques.
   offset = Math.trunc(offset);
-  // `x !== x`-style conditionals are a faster form of `isNaN(x)`
-  if (offset === 0 || offset !== offset) {
+  if (offset === 0) {
     return 0;
-  } else if (offset < 0) {
+  }
+  if (offset < 0) {
     offset += length;
     return offset > 0 ? offset : 0;
-  } else {
-    return offset < length ? offset : length;
   }
+  if (offset < length) {
+    return offset;
+  }
+  return Number.isNaN(offset) ? 0 : length;
 }
 
 
