@@ -46,6 +46,10 @@ const {
   assertEncoding,
   stringToFlags
 } = internalFS;
+const {
+  CHAR_FORWARD_SLASH,
+  CHAR_BACKWARD_SLASH,
+} = require('internal/constants');
 
 Object.defineProperty(exports, 'constants', {
   configurable: false,
@@ -456,7 +460,7 @@ function readFileAfterStat(err) {
   // our internal use.
   var size;
   if ((statValues[1/*mode*/] & S_IFMT) === S_IFREG)
-    size = context.size = statValues[8/*size*/];
+    size = context.size = statValues[8];
   else
     size = context.size = 0;
 
@@ -572,7 +576,7 @@ fs.readFileSync = function(path, options) {
   // our internal use.
   var size;
   if ((statValues[1/*mode*/] & S_IFMT) === S_IFREG)
-    size = statValues[8/*size*/];
+    size = statValues[8];
   else
     size = 0;
   var pos = 0;
@@ -1569,7 +1573,7 @@ if (isWindows) {
 } else {
   splitRoot = function splitRoot(str) {
     for (var i = 0; i < str.length; ++i) {
-      if (str.charCodeAt(i) !== 47/*'/'*/)
+      if (str.charCodeAt(i) !== CHAR_FORWARD_SLASH)
         return str.slice(0, i);
     }
     return str;
@@ -1593,7 +1597,9 @@ if (isWindows) {
   nextPart = function nextPart(p, i) {
     for (; i < p.length; ++i) {
       const ch = p.charCodeAt(i);
-      if (ch === 92/*'\'*/ || ch === 47/*'/'*/)
+
+      // Check for a separator character
+      if (ch === CHAR_BACKWARD_SLASH || ch === CHAR_FORWARD_SLASH)
         return i;
     }
     return -1;
@@ -1694,8 +1700,8 @@ fs.realpathSync = function realpathSync(p, options) {
       var linkTarget = null;
       var id;
       if (!isWindows) {
-        var dev = statValues[0/*dev*/].toString(32);
-        var ino = statValues[7/*ino*/].toString(32);
+        var dev = statValues[0].toString(32);
+        var ino = statValues[7].toString(32);
         id = `${dev}:${ino}`;
         if (seenLinks[id]) {
           linkTarget = seenLinks[id];
@@ -1831,8 +1837,8 @@ fs.realpath = function realpath(p, options, callback) {
     // dev/ino always return 0 on windows, so skip the check.
     let id;
     if (!isWindows) {
-      var dev = statValues[0/*ino*/].toString(32);
-      var ino = statValues[7/*ino*/].toString(32);
+      var dev = statValues[0].toString(32);
+      var ino = statValues[7].toString(32);
       id = `${dev}:${ino}`;
       if (seenLinks[id]) {
         return gotTarget(null, seenLinks[id], base);
