@@ -238,17 +238,7 @@ function flushStdio(subprocess) {
 
 
 function createSocket(pipe, readable) {
-  var s = new net.Socket({ handle: pipe });
-
-  if (readable) {
-    s.writable = false;
-    s.readable = true;
-  } else {
-    s.writable = true;
-    s.readable = false;
-  }
-
-  return s;
+  return net.Socket({ handle: pipe, readable, writable: !readable });
 }
 
 
