@@ -5,6 +5,7 @@
 require('internal/util').assertCrypto();
 
 const { async_id_symbol } = process.binding('async_wrap');
+const http = require('http');
 const binding = process.binding('http2');
 const assert = require('assert');
 const { Buffer } = require('buffer');
@@ -67,6 +68,8 @@ const NETServer = net.Server;
 const TLSServer = tls.Server;
 
 const kInspect = require('internal/util').customInspectSymbol;
+const { kIncomingMessage } = require('_http_common');
+const { kServerResponse } = require('_http_server');
 
 const kAlpnProtocol = Symbol('alpnProtocol');
 const kAuthority = Symbol('authority');
@@ -1409,18 +1412,6 @@ function afterDoStreamWrite(status, handle, req) {
   req.handle = undefined;
 }
 
-function onHandleFinish() {
-  const handle = this[kHandle];
-  if (this[kID] === undefined) {
-    this.once('ready', onHandleFinish);
-  } else if (handle !== undefined) {
-    const req = new ShutdownWrap();
-    req.oncomplete = () => {};
-    req.handle = handle;
-    handle.shutdown(req);
-  }
-}
-
 function streamOnResume() {
   if (!this.destroyed && !this.pending)
     this[kHandle].readStart();
@@ -1441,6 +1432,13 @@ function abort(stream) {
   }
 }
 
+function afterShutdown() {
+  this.callback();
+  const stream = this.handle[kOwner];
+  if (stream)
+    stream[kMaybeDestroy]();
+}
+
 // An Http2Stream is a Duplex stream that is backed by a
 // node::http2::Http2Stream handle implementing StreamBase.
 class Http2Stream extends Duplex {
@@ -1463,7 +1461,6 @@ class Http2Stream extends Duplex {
       writeQueueSize: 0
     };
 
-    this.once('finish', onHandleFinish);
     this.on('resume', streamOnResume);
     this.on('pause', streamOnPause);
   }
@@ -1669,6 +1666,23 @@ class Http2Stream extends Duplex {
     trackWriteState(this, req.bytes);
   }
 
+  _final(cb) {
+    const handle = this[kHandle];
+    if (this[kID] === undefined) {
+      this.once('ready', () => this._final(cb));
+    } else if (handle !== undefined) {
+      debug(`Http2Stream ${this[kID]} [Http2Session ` +
+            `${sessionName(this[kSession][kType])}]: _final shutting down`);
+      const req = new ShutdownWrap();
+      req.oncomplete = afterShutdown;
+      req.callback = cb;
+      req.handle = handle;
+      handle.shutdown(req);
+    } else {
+      cb();
+    }
+  }
+
   _read(nread) {
     if (this.destroyed) {
       this.push(null);
@@ -1876,7 +1890,7 @@ function processRespondWithFD(self, fd, headers, offset = 0, length = -1,
     return;
   }
   // exact length of the file doesn't matter here, since the
-  // stream is closing anyway — just use 1 to signify that
+  // stream is closing anyway - just use 1 to signify that
   // a write does exist
   trackWriteState(self, 1);
 }
@@ -2442,8 +2456,11 @@ function connectionListener(socket) {
 
   if (socket.alpnProtocol === false || socket.alpnProtocol === 'http/1.1') {
     // Fallback to HTTP/1.1
-    if (options.allowHTTP1 === true)
+    if (options.allowHTTP1 === true) {
+      socket.server[kIncomingMessage] = options.Http1IncomingMessage;
+      socket.server[kServerResponse] = options.Http1ServerResponse;
       return httpConnectionListener.call(this, socket);
+    }
     // Let event handler deal with the socket
     if (!this.emit('unknownProtocol', socket))
       socket.destroy();
@@ -2474,6 +2491,17 @@ function initializeOptions(options) {
   options.allowHalfOpen = true;
   assertIsObject(options.settings, 'options.settings');
   options.settings = Object.assign({}, options.settings);
+
+  // Used only with allowHTTP1
+  options.Http1IncomingMessage = options.Http1IncomingMessage ||
+    http.IncomingMessage;
+  options.Http1ServerResponse = options.Http1ServerResponse ||
+    http.ServerResponse;
+
+  options.Http2ServerRequest = options.Http2ServerRequest ||
+                                       Http2ServerRequest;
+  options.Http2ServerResponse = options.Http2ServerResponse ||
+                                        Http2ServerResponse;
   return options;
 }
 
@@ -2539,7 +2567,11 @@ class Http2Server extends NETServer {
 function setupCompat(ev) {
   if (ev === 'request') {
     this.removeListener('newListener', setupCompat);
-    this.on('stream', onServerStream);
+    this.on('stream', onServerStream.bind(
+      this,
+      this[kOptions].Http2ServerRequest,
+      this[kOptions].Http2ServerResponse)
+    );
   }
 }
 
