@@ -158,8 +158,8 @@ function setupKillAndExit() {
     }
 
     // preserve null signal
-    if (0 === sig) {
-      err = process._kill(pid, 0);
+    if (sig === (sig | 0)) {
+      err = process._kill(pid, sig);
     } else {
       sig = sig || 'SIGTERM';
       if (constants[sig]) {
