@@ -48,7 +48,7 @@ function setupNextTick() {
   const promises = require('internal/process/promises');
   const errors = require('internal/errors');
   const emitPendingUnhandledRejections = promises.setup(scheduleMicrotasks);
-  const initTriggerId = async_hooks.initTriggerId;
+  const getDefaultTriggerAsyncId = async_hooks.getDefaultTriggerAsyncId;
   // Two arrays that share state between C++ and JS.
   const { async_hook_fields, async_id_fields } = async_wrap;
   // Used to change the state of the async id stack.
@@ -210,7 +210,7 @@ function setupNextTick() {
     nextTickQueue.push(new TickObject(callback,
                                       args,
                                       ++async_id_fields[kAsyncIdCounter],
-                                      initTriggerId()));
+                                      getDefaultTriggerAsyncId()));
   }
 
   // `internalNextTick()` will not enqueue any callback when the process is
@@ -237,7 +237,7 @@ function setupNextTick() {
     }
 
     if (triggerAsyncId === null)
-      triggerAsyncId = initTriggerId();
+      triggerAsyncId = getDefaultTriggerAsyncId();
     // In V8 6.2, moving tickInfo & async_id_fields[kAsyncIdCounter] into the
     // TickObject incurs a significant performance penalty in the
     // next-tick-breadth-args benchmark (revisit later)
