@@ -12,6 +12,12 @@ const noCrypto = !process.versions.openssl;
 
 const experimentalWarnings = new Set();
 
+const colorRegExp = /\u001b\[\d\d?m/g;
+
+function removeColors(str) {
+  return str.replace(colorRegExp, '');
+}
+
 function isError(e) {
   return objectToString(e) === '[object Error]' || e instanceof Error;
 }
@@ -297,6 +303,7 @@ module.exports = {
   objectToString,
   promisify,
   spliceOne,
+  removeColors,
 
   // Symbol used to customize promisify conversion
   customPromisifyArgs: kCustomPromisifyArgsSymbol,
