@@ -79,7 +79,7 @@ var line = '';
 
 function peekline() {
   const s = readline();
-  line = s + '\n' + line;
+  line = `${s}\n${line}`;
   return s;
 }
 
