@@ -1,4 +1,7 @@
-/* eslint-disable strict */
+'use strict';
+
+const vm = require('vm');
+
 const scriptFiles = [
   'internal/v8_prof_polyfill',
   'v8/tools/splaytree',
@@ -18,15 +21,21 @@ scriptFiles.forEach(function(s) {
   script += process.binding('natives')[s] + '\n';
 });
 
-var tickArguments = [];
+// eslint-disable-next-line no-unused-vars
+function printErr(err) {
+  console.error(err);
+}
+
+const tickArguments = [];
 if (process.platform === 'darwin') {
   tickArguments.push('--mac');
 } else if (process.platform === 'win32') {
   tickArguments.push('--windows');
 }
 tickArguments.push.apply(tickArguments, process.argv.slice(1));
-script = `(function() {
+script = `(function(require) {
   arguments = ${JSON.stringify(tickArguments)};
+  function write (s) { process.stdout.write(s) }
   ${script}
-})()`;
-eval(script);
+})`;
+vm.runInThisContext(script)(require);
