@@ -45,7 +45,7 @@ module.exports = Module;
 // these are below module.exports for the circular reference
 const Loader = require('internal/loader/Loader');
 const ModuleJob = require('internal/loader/ModuleJob');
-const { createDynamicModule } = require('internal/loader/ModuleWrap');
+const createDynamicModule = require('internal/loader/CreateDynamicModule');
 let ESMLoader;
 
 function stat(filename) {
@@ -464,11 +464,13 @@ Module._load = function(request, parent, isMain) {
         ESMLoader = new Loader();
         const userLoader = process.binding('config').userLoader;
         if (userLoader) {
+          ESMLoader.isMain = false;
           const hooks = await ESMLoader.import(userLoader);
           ESMLoader = new Loader();
           ESMLoader.hook(hooks);
         }
       }
+      Loader.registerImportDynamicallyCallback(ESMLoader);
       await ESMLoader.import(getURLFromFilePath(request).pathname);
     })()
     .catch((e) => {
