@@ -90,6 +90,7 @@ const TIMEOUT_MAX = 2 ** 31 - 1;
 // TimerWrap C++ handle, which makes the call after the duration to process the
 // list it is attached to.
 //
+/* eslint-disable non-ascii-character */
 //
 // ╔════ > Object Map
 // ║
@@ -111,6 +112,7 @@ const TIMEOUT_MAX = 2 ** 31 - 1;
 // ║
 // ╚════ > Linked List
 //
+/* eslint-enable non-ascii-character */
 //
 // With this, virtually constant-time insertion (append), removal, and timeout
 // is possible in the JavaScript layer. Any one list of timers is able to be
@@ -603,7 +605,6 @@ Timeout.prototype.unref = function() {
     this._handle.owner = this;
     this._handle[kOnTimeout] = unrefdHandle;
     this._handle.start(delay);
-    this._handle.domain = this.domain;
     this._handle.unref();
   }
   return this;
