@@ -883,7 +883,7 @@ Url.prototype.resolveObject = function resolveObject(relative) {
 
   // if the path is allowed to go above the root, restore leading ..s
   if (!mustEndAbs && !removeAllDots) {
-    for (; up--; up) {
+    while (up--) {
       srcPath.unshift('..');
     }
   }
