@@ -207,5 +207,8 @@ module.exports = {
   runInContext,
   runInNewContext,
   runInThisContext,
-  isContext
+  isContext,
 };
+
+if (process.binding('config').experimentalVMModules)
+  module.exports.Module = require('internal/vm/Module').Module;
