@@ -39,16 +39,20 @@ void inline debug_vfprintf(const char* format, ...) {
 #define DEBUG_HTTP2(...) debug_vfprintf(__VA_ARGS__);
 #define DEBUG_HTTP2SESSION(session, message)                                  \
   do {                                                                        \
-    DEBUG_HTTP2("Http2Session %s (%.0lf) " message "\n",                      \
-                   session->TypeName(),                                       \
-                   session->get_async_id());                                  \
+    if (session != nullptr) {                                                 \
+      DEBUG_HTTP2("Http2Session %s (%.0lf) " message "\n",                    \
+                  session->TypeName(),                                        \
+                  session->get_async_id());                                   \
+     }                                                                        \
   } while (0)
 #define DEBUG_HTTP2SESSION2(session, message, ...)                            \
   do {                                                                        \
-    DEBUG_HTTP2("Http2Session %s (%.0lf) " message "\n",                      \
-                   session->TypeName(),                                       \
-                   session->get_async_id(),                                   \
+    if (session != nullptr) {                                                 \
+      DEBUG_HTTP2("Http2Session %s (%.0lf) " message "\n",                    \
+                  session->TypeName(),                                        \
+                  session->get_async_id(),                                    \
                   __VA_ARGS__);                                               \
+    }                                                                         \
   } while (0)
 #define DEBUG_HTTP2STREAM(stream, message)                                    \
   do {                                                                        \
