@@ -5,7 +5,8 @@ const fs = require('fs');
 const http = require('http');
 const fixtures = require('../common/fixtures');
 const { spawn } = require('child_process');
-const url = require('url');
+const { parse: parseURL } = require('url');
+const { getURLFromFilePath } = require('internal/url');
 
 const _MAINSCRIPT = fixtures.path('loop.js');
 const DEBUG = false;
@@ -167,12 +168,13 @@ class InspectorSession {
         reject(message.error);
     } else {
       if (message.method === 'Debugger.scriptParsed') {
-        const script = message['params'];
-        const scriptId = script['scriptId'];
-        const url = script['url'];
+        const { scriptId, url } = message.params;
         this._scriptsIdsByUrl.set(scriptId, url);
-        if (url === _MAINSCRIPT)
+        const fileUrl = url.startsWith('file:') ?
+          url : getURLFromFilePath(url).toString();
+        if (fileUrl === this.scriptURL().toString()) {
           this.mainScriptId = scriptId;
+        }
       }
 
       if (this._notificationCallback) {
@@ -188,12 +190,12 @@ class InspectorSession {
 
   _sendMessage(message) {
     const msg = JSON.parse(JSON.stringify(message)); // Clone!
-    msg['id'] = this._nextId++;
+    msg.id = this._nextId++;
     if (DEBUG)
       console.log('[sent]', JSON.stringify(msg));
 
     const responsePromise = new Promise((resolve, reject) => {
-      this._commandResponsePromises.set(msg['id'], { resolve, reject });
+      this._commandResponsePromises.set(msg.id, { resolve, reject });
     });
 
     return new Promise(
@@ -238,12 +240,15 @@ class InspectorSession {
     return notification;
   }
 
-  _isBreakOnLineNotification(message, line, url) {
-    if ('Debugger.paused' === message['method']) {
-      const callFrame = message['params']['callFrames'][0];
-      const location = callFrame['location'];
-      assert.strictEqual(url, this._scriptsIdsByUrl.get(location['scriptId']));
-      assert.strictEqual(line, location['lineNumber']);
+  _isBreakOnLineNotification(message, line, expectedScriptPath) {
+    if ('Debugger.paused' === message.method) {
+      const callFrame = message.params.callFrames[0];
+      const location = callFrame.location;
+      const scriptPath = this._scriptsIdsByUrl.get(location.scriptId);
+      assert.strictEqual(scriptPath.toString(),
+                         expectedScriptPath.toString(),
+                         `${scriptPath} !== ${expectedScriptPath}`);
+      assert.strictEqual(line, location.lineNumber);
       return true;
     }
   }
@@ -259,12 +264,12 @@ class InspectorSession {
   _matchesConsoleOutputNotification(notification, type, values) {
     if (!Array.isArray(values))
       values = [ values ];
-    if ('Runtime.consoleAPICalled' === notification['method']) {
-      const params = notification['params'];
-      if (params['type'] === type) {
+    if ('Runtime.consoleAPICalled' === notification.method) {
+      const params = notification.params;
+      if (params.type === type) {
         let i = 0;
-        for (const value of params['args']) {
-          if (value['value'] !== values[i++])
+        for (const value of params.args) {
+          if (value.value !== values[i++])
             return false;
         }
         return i === values.length;
@@ -291,12 +296,26 @@ class InspectorSession {
               'Waiting for the debugger to disconnect...');
     await this.disconnect();
   }
+
+  scriptPath() {
+    return this._instance.scriptPath();
+  }
+
+  script() {
+    return this._instance.script();
+  }
+
+  scriptURL() {
+    return getURLFromFilePath(this.scriptPath());
+  }
 }
 
 class NodeInstance {
   constructor(inspectorFlags = ['--inspect-brk=0'],
               scriptContents = '',
               scriptFile = _MAINSCRIPT) {
+    this._scriptPath = scriptFile;
+    this._script = scriptFile ? null : scriptContents;
     this._portCallback = null;
     this.portPromise = new Promise((resolve) => this._portCallback = resolve);
     this._process = spawnChildProcess(inspectorFlags, scriptContents,
@@ -371,11 +390,11 @@ class NodeInstance {
 
   async sendUpgradeRequest() {
     const response = await this.httpGet(null, '/json/list');
-    const devtoolsUrl = response[0]['webSocketDebuggerUrl'];
+    const devtoolsUrl = response[0].webSocketDebuggerUrl;
     const port = await this.portPromise;
     return http.get({
       port,
-      path: url.parse(devtoolsUrl).path,
+      path: parseURL(devtoolsUrl).path,
       headers: {
         'Connection': 'Upgrade',
         'Upgrade': 'websocket',
@@ -425,10 +444,16 @@ class NodeInstance {
   kill() {
     this._process.kill();
   }
-}
 
-function readMainScriptSource() {
-  return fs.readFileSync(_MAINSCRIPT, 'utf8');
+  scriptPath() {
+    return this._scriptPath;
+  }
+
+  script() {
+    if (this._script === null)
+      this._script = fs.readFileSync(this.scriptPath(), 'utf8');
+    return this._script;
+  }
 }
 
 function onResolvedOrRejected(promise, callback) {
@@ -469,7 +494,5 @@ function fires(promise, error, timeoutMs) {
 }
 
 module.exports = {
-  mainScriptPath: _MAINSCRIPT,
-  readMainScriptSource,
   NodeInstance
 };
