@@ -38,9 +38,9 @@ assert.throws(() => Buffer.compare(Buffer.alloc(1), 'abc'), errMsg);
 
 assert.throws(() => Buffer.compare('abc', Buffer.alloc(1)), errMsg);
 
-assert.throws(() => Buffer.alloc(1).compare('abc'), common.expectsError({
+common.expectsError(() => Buffer.alloc(1).compare('abc'), {
   code: 'ERR_INVALID_ARG_TYPE',
   type: TypeError,
   message: 'The "target" argument must be one of ' +
            'type Buffer or Uint8Array. Received type string'
-}));
+});
