@@ -13,10 +13,9 @@ const syntaxArgs = [
   ['--check']
 ];
 
-const syntaxErrorRE = common.engineSpecificMessage({
-  v8: /^SyntaxError: Unexpected identifier$/m,
-  chakracore: /^SyntaxError: Expected ';'$/m
-});
+// Match on the name of the `Error` but not the message as it is different
+// depending on the JavaScript engine.
+const syntaxErrorRE = /^SyntaxError: \b/m;
 const notFoundRE = /^Error: Cannot find module/m;
 
 // test good syntax with and without shebang
@@ -114,9 +113,7 @@ syntaxArgs.forEach(function(args) {
   const c = spawnSync(node, args, { encoding: 'utf8', input: stdin });
 
   // stderr should include '[stdin]' as the filename
-  if (!common.isChakraEngine) {
-    assert(c.stderr.startsWith('[stdin]'), `${c.stderr} starts with ${stdin}`);
-  }
+  assert(c.stderr.startsWith('[stdin]'), `${c.stderr} starts with ${stdin}`);
 
   // no stdout or stderr should be produced
   assert.strictEqual(c.stdout, '');
