@@ -14,25 +14,25 @@ net.Server().listen(0, function() {
 });
 
 // The first argument is a configuration object
-assert.throws(() => {
+common.expectsError(() => {
   net.Server().listen({ port: invalidPort }, common.mustNotCall());
-}, common.expectsError({
+}, {
   code: 'ERR_SOCKET_BAD_PORT',
   type: RangeError
-}));
+});
 
 // The first argument is the port, no IP given.
-assert.throws(() => {
+common.expectsError(() => {
   net.Server().listen(invalidPort, common.mustNotCall());
-}, common.expectsError({
+}, {
   code: 'ERR_SOCKET_BAD_PORT',
   type: RangeError
-}));
+});
 
 // The first argument is the port, the second an IP.
-assert.throws(() => {
+common.expectsError(() => {
   net.Server().listen(invalidPort, '0.0.0.0', common.mustNotCall());
-}, common.expectsError({
+}, {
   code: 'ERR_SOCKET_BAD_PORT',
   type: RangeError
-}));
+});
