@@ -1,10 +1,9 @@
 'use strict';
 
 const common = require('../common');
-if (!common.hasIntl) {
+if (!common.hasIntl)
   common.skip('missing Intl');
-  return;
-}
+
 const assert = require('assert');
 const url = require('url');
 const URL = url.URL;
@@ -25,8 +24,8 @@ assert.strictEqual(
   const expectedErr = common.expectsError({
     code: 'ERR_INVALID_ARG_TYPE',
     type: TypeError,
-    message: 'The "options" argument must be of type object'
-  });
+    message: 'The "options" argument must be of type Object'
+  }, 4);
   assert.throws(() => url.format(myURL, true), expectedErr);
   assert.throws(() => url.format(myURL, 1), expectedErr);
   assert.throws(() => url.format(myURL, 'test'), expectedErr);
@@ -37,80 +36,76 @@ assert.strictEqual(
 // Any truthy value will be treated as true.
 
 assert.strictEqual(
-  url.format(myURL, {fragment: false}),
+  url.format(myURL, { fragment: false }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b'
 );
 
 assert.strictEqual(
-  url.format(myURL, {fragment: ''}),
+  url.format(myURL, { fragment: '' }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b'
 );
 
 assert.strictEqual(
-  url.format(myURL, {fragment: 0}),
+  url.format(myURL, { fragment: 0 }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b'
 );
 
 assert.strictEqual(
-  url.format(myURL, {fragment: 1}),
+  url.format(myURL, { fragment: 1 }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b#c'
 );
 
 assert.strictEqual(
-  url.format(myURL, {fragment: {}}),
+  url.format(myURL, { fragment: {} }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b#c'
 );
 
 assert.strictEqual(
-  url.format(myURL, {search: false}),
+  url.format(myURL, { search: false }),
   'http://xn--lck1c3crb1723bpq4a.com/a#c'
 );
 
 assert.strictEqual(
-  url.format(myURL, {search: ''}),
+  url.format(myURL, { search: '' }),
   'http://xn--lck1c3crb1723bpq4a.com/a#c'
 );
 
 assert.strictEqual(
-  url.format(myURL, {search: 0}),
+  url.format(myURL, { search: 0 }),
   'http://xn--lck1c3crb1723bpq4a.com/a#c'
 );
 
 assert.strictEqual(
-  url.format(myURL, {search: 1}),
+  url.format(myURL, { search: 1 }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b#c'
 );
 
 assert.strictEqual(
-  url.format(myURL, {search: {}}),
+  url.format(myURL, { search: {} }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b#c'
 );
 
-// Unicode conversion in node code is dependent on
-// v8's i18n support which is disabled for chakracore
-if (!common.isChakraEngine) {
-  assert.strictEqual(
-  url.format(myURL, {unicode: true}),
+assert.strictEqual(
+  url.format(myURL, { unicode: true }),
   'http://理容ナカムラ.com/a?a=b#c'
-  );
-
-  assert.strictEqual(
-    url.format(myURL, {unicode: 1}),
-    'http://理容ナカムラ.com/a?a=b#c'
-  );
-
-  assert.strictEqual(
-    url.format(myURL, {unicode: {}}),
-    'http://理容ナカムラ.com/a?a=b#c'
-  );
-}
+);
 
 assert.strictEqual(
-  url.format(myURL, {unicode: false}),
+  url.format(myURL, { unicode: 1 }),
+  'http://理容ナカムラ.com/a?a=b#c'
+);
+
+assert.strictEqual(
+  url.format(myURL, { unicode: {} }),
+  'http://理容ナカムラ.com/a?a=b#c'
+);
+
+assert.strictEqual(
+  url.format(myURL, { unicode: false }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b#c'
 );
 
 assert.strictEqual(
-  url.format(myURL, {unicode: 0}),
+  url.format(myURL, { unicode: 0 }),
   'http://xn--lck1c3crb1723bpq4a.com/a?a=b#c'
 );
