@@ -38,20 +38,20 @@ test(function() {
 // Tests below are not from WPT.
 {
   const params = new URLSearchParams();
-  assert.throws(() => {
+  common.expectsError(() => {
     params.set.call(undefined);
-  }, common.expectsError({
+  }, {
     code: 'ERR_INVALID_THIS',
     type: TypeError,
     message: 'Value of "this" must be of type URLSearchParams'
-  }));
-  assert.throws(() => {
+  });
+  common.expectsError(() => {
     params.set('a');
-  }, common.expectsError({
+  }, {
     code: 'ERR_MISSING_ARGS',
     type: TypeError,
     message: 'The "name" and "value" arguments must be specified'
-  }));
+  });
 
   const obj = {
     toString() { throw new Error('toString'); },
@@ -60,18 +60,8 @@ test(function() {
   const sym = Symbol();
   assert.throws(() => params.append(obj, 'b'), /^Error: toString$/);
   assert.throws(() => params.append('a', obj), /^Error: toString$/);
-  assert.throws(
-    () => params.append(sym, 'b'),
-    common.engineSpecificMessage({
-      v8: /^TypeError: Cannot convert a Symbol value to a string$/,
-      chakracore: /^TypeError: Object doesn't support property or method 'ToString'/
-    })
-  );
-  assert.throws(
-    () => params.append('a', sym),
-    common.engineSpecificMessage({
-      v8: /^TypeError: Cannot convert a Symbol value to a string$/,
-      chakracore: /^TypeError: Object doesn't support property or method 'ToString'/
-    })
-  );
+  assert.throws(() => params.append(sym, 'b'),
+                /^TypeError: Cannot convert a Symbol value to a string$/);
+  assert.throws(() => params.append('a', sym),
+                /^TypeError: Cannot convert a Symbol value to a string$/);
 }
