@@ -1,3 +1,4 @@
+// Flags: --expose-internals
 'use strict';
 const common = require('../common');
 common.skipIfInspectorDisabled();
@@ -5,7 +6,7 @@ const assert = require('assert');
 const { NodeInstance } = require('../common/inspector-helper.js');
 
 async function runTests() {
-  const child = new NodeInstance(['--inspect=0'],
+  const child = new NodeInstance(['--inspect-brk=0'],
                                  `let c = 0;
                                   const interval = setInterval(() => {
                                    console.log(new Object());
