@@ -61,10 +61,7 @@ class SimpleTestCase(test.TestCase):
     source = open(self.file).read()
     flags_match = FLAGS_PATTERN.search(source)
     if flags_match:
-      # PORT should match the definition in test/common/index.js.
-      env = { 'PORT': int(os.getenv('NODE_COMMON_PORT', '12346')) }
-      env['PORT'] += self.thread_id * 100
-      flag = flags_match.group(1).strip().format(**env).split()
+      flag = flags_match.group(1).strip().split()
       # The following block reads config.gypi to extract the v8_enable_inspector
       # value. This is done to check if the inspector is disabled in which case
       # the '--inspect' flag cannot be passed to the node process as it will
@@ -111,7 +108,7 @@ class SimpleTestConfiguration(test.TestConfiguration):
   def Ls(self, path):
     return [f for f in os.listdir(path) if re.match('^test-.*\.m?js$', f)]
 
-  def ListTests(self, current_path, path, arch, mode, jsEngine):
+  def ListTests(self, current_path, path, arch, mode):
     all_tests = [current_path + [t] for t in self.Ls(join(self.root))]
     result = []
     for test in all_tests:
@@ -135,9 +132,9 @@ class ParallelTestConfiguration(SimpleTestConfiguration):
     super(ParallelTestConfiguration, self).__init__(context, root, section,
                                                     additional)
 
-  def ListTests(self, current_path, path, arch, mode, jsEngine):
+  def ListTests(self, current_path, path, arch, mode):
     result = super(ParallelTestConfiguration, self).ListTests(
-         current_path, path, arch, mode, jsEngine)
+         current_path, path, arch, mode)
     for test in result:
       test.parallel = True
     return result
@@ -158,7 +155,7 @@ class AddonTestConfiguration(SimpleTestConfiguration):
             result.append([subpath, f[:-3]])
     return result
 
-  def ListTests(self, current_path, path, arch, mode, jsEngine):
+  def ListTests(self, current_path, path, arch, mode):
     all_tests = [current_path + t for t in self.Ls(join(self.root))]
     result = []
     for test in all_tests:
@@ -173,9 +170,9 @@ class AsyncHooksTestConfiguration(SimpleTestConfiguration):
     super(AsyncHooksTestConfiguration, self).__init__(context, root, section,
                                                     additional)
 
-  def ListTests(self, current_path, path, arch, mode, jsEngine):
+  def ListTests(self, current_path, path, arch, mode):
     result = super(AsyncHooksTestConfiguration, self).ListTests(
-         current_path, path, arch, mode, jsEngine)
+         current_path, path, arch, mode)
     for test in result:
       test.parallel = True
     return result
@@ -185,9 +182,9 @@ class AbortTestConfiguration(SimpleTestConfiguration):
     super(AbortTestConfiguration, self).__init__(context, root, section,
                                                  additional)
 
-  def ListTests(self, current_path, path, arch, mode, jsEngine):
+  def ListTests(self, current_path, path, arch, mode):
     result = super(AbortTestConfiguration, self).ListTests(
-         current_path, path, arch, mode, jsEngine)
+         current_path, path, arch, mode)
     for test in result:
       test.disable_core_files = True
     return result
